<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="226"/>
        <source>Drop Error</source>
        <translation>Erro na colocação</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>O arquivo/URL &apos;%1&apos; não pôde ser incorporado ao lançador rápido por enquanto</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="333"/>
        <source>Drop application
icons here</source>
        <translation>Arraste ícones de
aplicativos para cá</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + Arrastar e Soltar)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Mover para a esquerda</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Mover para a direita</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="64"/>
        <source>Remove from quicklaunch</source>
        <translation>Remover do lançador rápido</translation>
    </message>
</context>
</TS>
